@@ -4,11 +4,11 @@ use crate::file::replace_path;
 use indexmap::IndexSet;
 use itertools::Itertools;
 use log::LevelFilter;
-use once_cell::sync::Lazy;
 use std::collections::{HashMap, HashSet};
 pub use std::env::*;
 use std::path::PathBuf;
 use std::string::ToString;
+use std::sync::LazyLock as Lazy;
 use std::sync::RwLock;
 use std::{path, process};
 
@@ -23,8 +23,12 @@ pub static SHELL: Lazy<String> = Lazy::new(|| var("COMSPEC").unwrap_or_else(|_|
 pub static HOME: Lazy<PathBuf> =
     Lazy::new(|| PathBuf::from(env!("CARGO_MANIFEST_DIR")).join("test"));
 #[cfg(not(test))]
-pub static HOME: Lazy<PathBuf> =
-    Lazy::new(|| home::home_dir().unwrap_or_else(|| PathBuf::from("/")));
+pub static HOME: Lazy<PathBuf> = Lazy::new(|| {
+    homedir::my_home()
+        .ok()
+        .flatten()
+        .unwrap_or_else(|| PathBuf::from("/"))
+});
 
 pub static EDITOR: Lazy<String> =
     Lazy::new(|| var("VISUAL").unwrap_or_else(|_| var("EDITOR").unwrap_or_else(|_| "nano".into())));
@@ -119,6 +123,19 @@ pub static MISE_GLOBAL_CONFIG_ROOT: Lazy<PathBuf> =
 pub static MISE_SYSTEM_CONFIG_FILE: Lazy<PathBuf> = Lazy::new(|| {
     var_path("MISE_SYSTEM_CONFIG_FILE").unwrap_or_else(|| MISE_SYSTEM_DIR.join("config.toml"))
 });
+pub static MISE_IGNORED_CONFIG_PATHS: Lazy<Vec<PathBuf>> = Lazy::new(|| {
+    var("MISE_IGNORED_CONFIG_PATHS")
+        .ok()
+        .map(|v| {
+            v.split(':')
+                .filter(|p| !p.is_empty())
+                .map(PathBuf::from)
+                .map(replace_path)
+                .collect()
+        })
+        .unwrap_or_default()
+});
+pub static MISE_TASK_LEVEL: Lazy<u8> = Lazy::new(|| var_u8("MISE_TASK_LEVEL"));
 pub static MISE_USE_TOML: Lazy<bool> = Lazy::new(|| !var_is_false("MISE_USE_TOML"));
 pub static MISE_LIST_ALL_VERSIONS: Lazy<bool> = Lazy::new(|| var_is_true("MISE_LIST_ALL_VERSIONS"));
 pub static ARGV0: Lazy<String> = Lazy::new(|| ARGS.read().unwrap()[0].to_string());
@@ -271,18 +288,6 @@ pub static MISE_NODE_DEFAULT_PACKAGES_FILE: Lazy<PathBuf> = Lazy::new(|| {
         HOME.join(".default-npm-packages")
     })
 });
-pub static MISE_IGNORED_CONFIG_PATHS: Lazy<Vec<PathBuf>> = Lazy::new(|| {
-    var("MISE_IGNORED_CONFIG_PATHS")
-        .ok()
-        .map(|v| {
-            v.split(':')
-                .filter(|p| !p.is_empty())
-                .map(PathBuf::from)
-                .map(replace_path)
-                .collect()
-        })
-        .unwrap_or_default()
-});
 pub static MISE_NODE_COREPACK: Lazy<bool> = Lazy::new(|| var_is_true("MISE_NODE_COREPACK"));
 pub static NVM_DIR: Lazy<PathBuf> =
     Lazy::new(|| var_path("NVM_DIR").unwrap_or_else(|| HOME.join(".nvm")));
